@@ -1,12 +1,17 @@
-#[derive(Copy, Clone, Debug, Default, PartialEq, Eq)]
+#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 pub enum Status {
     Success,
     Failure,
-    #[default]
     Running,
     // Initialized,
 }
 
+impl core::default::Default for Status {
+    fn default() -> Self {
+        Self::Running
+    }
+}
+
 #[derive(Clone, Debug)]
 pub struct TreeRepr {
     pub name: &'static str,
@@ -34,14 +39,19 @@ impl TreeRepr {
     }
 }
 
-#[derive(Debug, Default)]
+#[derive(Debug)]
 pub enum Cursor {
     // Condition(bool),
     Index(usize, Box<DebugRepr>),
-    #[default]
     Leaf,
 }
 
+impl core::default::Default for Cursor {
+    fn default() -> Self {
+        Self::Leaf
+    }
+}
+
 impl Cursor {
     pub fn index(&self) -> usize {
         match self {
@@ -56,7 +66,7 @@ pub struct DebugRepr {
     pub name: String,
     pub params: Option<String>,
     pub status: Status,
-
+    pub bool_override: Option<bool>,
     pub cursor: Cursor,
 }
 
@@ -66,7 +76,15 @@ impl DebugRepr {
             name: name.to_string(),
             cursor,
             status,
+            bool_override: None,
             params: None,
         }
     }
+
+    pub fn with_override(self, bool_override: bool) -> Self {
+        Self {
+            bool_override: Some(bool_override),
+            ..self
+        }
+    }
 }
